function [swcf]= SWCF_initialize(im,initRect, paddingin)
swcf = [];
swcf.flag = 0;
swcf.maxResponse = 0;
swcf.psr = 0;
swcf.psrs = [];
swcf.psrPrev = 0;
swcf.Tpsr = 0;
swcf.Q = 0;
swcf.global = 0;
swcf.hflong_den = [];
swcf.Hwindowed = [];
if size(im, 3) == 3
    swcf.modelroi = rgb2gray(getROI(im, initRect));
else
    swcf.modelroi = getROI(im, initRect);
end
swcf.rect = initRect;
%parameters according to the paper
params.padding = paddingin;         			% extra area surrounding the target
params.output_sigma_factor = 1/16;		% standard deviation for the desired translation filter output
params.scale_sigma_factor = 1/4;        % standard deviation for the desired scale filter output
params.lambda = 1e-2;					% regularization weight (denoted "lambda" in the paper)
params.learning_rate = 0.025;			% tracking model learning rate (denoted "eta" in the paper)
params.number_of_scales = 33;           % number of scale levels (denoted "S" in the paper)
params.scale_step = 1.02;               % Scale increment factor (denoted "a" in the paper)
params.scale_model_max_area = 512;      % the maximum size of scale examples
params.visualization = 1;

swcf.params = params;

pos = initRect(2:-1:1);
target_sz = initRect(4:-1:3);

% params.init_pos = floor(pos) + floor(target_sz/2);
params.init_pos = floor(pos + (target_sz)/2); %Erhan changed
params.wsize = round(target_sz); %Erhan changed from floor to round

% [positions, fps] = swcf(params)

% parameters
swcf.padding = params.padding;                         	%extra area surrounding the target
swcf.output_sigma_factor = params.output_sigma_factor;	%spatial bandwidth (proportional to target)
swcf.lambda = params.lambda;
swcf.learning_rate = params.learning_rate;
swcf.nScales = params.number_of_scales;
swcf.scale_step = params.scale_step;
swcf.scale_sigma_factor = params.scale_sigma_factor;
swcf.scale_model_max_area = params.scale_model_max_area;

% video_path = params.video_path;
% img_files = params.img_files;
swcf.pos = floor(params.init_pos);
swcf.target_sz = floor(params.wsize);

swcf.visualization = params.visualization;

% num_frames = numel(img_files);

swcf.init_target_sz = target_sz;

% target size att scale = 1
swcf.base_target_sz = target_sz;

% window size, taking padding into account
swcf.sz = floor(swcf.base_target_sz * (1 + swcf.padding)); %Erhan changed

% desired translation filter output (gaussian shaped), bandwidth
% proportional to target size
swcf.output_sigma = sqrt(prod(swcf.base_target_sz)) * swcf.output_sigma_factor;
[rs, cs] = ndgrid((1:swcf.sz(1)) - floor(swcf.sz(1)/2), (1:swcf.sz(2)) - floor(swcf.sz(2)/2));
y = exp(-0.5 * (((rs.^2 + cs.^2) / swcf.output_sigma^2)));
swcf.yf = single(fft2(y));
swcf.y = single(y);

% desired scale filter output (gaussian shaped), bandwidth proportional to
% number of scales
swcf.scale_sigma = swcf.nScales/sqrt(33) * swcf.scale_sigma_factor;
ss = (1:swcf.nScales) - ceil(swcf.nScales/2);
ys = exp(-0.5 * (ss.^2) / swcf.scale_sigma^2);
swcf.ysf = single(fft(ys));

% store pre-computed translation filter cosine window
swcf.cos_window = single(hann(swcf.sz(1)) * hann(swcf.sz(2))');
swcf.cos_window_fixed = single(hann(swcf.sz(1)) * hann(swcf.sz(2))');
% swcf.cos_window_fixed = single(f2dgauss([swcf.sz(1) swcf.sz(2)],0.15*[swcf.sz(1) swcf.sz(2)]));
swcf.plain_window = ones(swcf.sz(1:2));
% store pre-computed scale filter cosine window
if mod(swcf.nScales,2) == 0
    scale_window = single(hann(swcf.nScales+1));
    swcf.scale_window = scale_window;
    swcf.scale_window = scale_window(2:end);
else
    swcf.scale_window = single(hann(swcf.nScales));
end;

% scale factors
ss = 1:swcf.nScales;
swcf.scaleFactorsX = swcf.scale_step.^(ceil(swcf.nScales/2) - ss);
swcf.scaleFactorsY = swcf.scale_step.^(ceil(swcf.nScales/2) - ss);

% compute the resize dimensions used for feature extraction in the scale
% estimation
swcf.scale_model_factor = 1;
if prod(swcf.init_target_sz) > swcf.scale_model_max_area
    swcf.scale_model_factor = sqrt(swcf.scale_model_max_area/prod(swcf.init_target_sz));
end
swcf.scale_model_sz = floor(swcf.init_target_sz * swcf.scale_model_factor);

swcf.currentScaleFactorX = 1;
swcf.currentScaleFactorY = 1;

% to calculate precision
% positions = zeros(numel(img_files), 4);

% to calculate FPS
swcf.time = 0;

% find maximum and minimum scales
% im = imread([video_path img_files{1}]);
swcf.min_scale_factor = swcf.scale_step ^ ceil(log(max(5 ./ swcf.sz)) / log(swcf.scale_step));
swcf.max_scale_factor = swcf.scale_step ^ floor(log(min([size(im,1) size(im,2)] ./ swcf.base_target_sz)) / log(swcf.scale_step));
[swcf]= SWCF_after_initialize(swcf,im);
end