function [swcf]= SWCF_track(swcf,im,frame)
pos = swcf.pos;
sz = swcf.sz;
tic;

if swcf.flag == 1 %frame > 1
    % extract the test sample feature map for the translation filter
    xt = get_translation_sample(im, pos, sz, [swcf.currentScaleFactorX swcf.currentScaleFactorY], swcf.cos_window_fixed);
    
    % calculate the correlation response of the translation filter
    xtf = fft2(xt);
    response = real(ifft2(sum(swcf.hf_num .* xtf, 3) ./ (swcf.hf_den + swcf.lambda)));
    
    % find the maximum translation response
    [row, col] = find(response == max(response(:)), 1);
    %% a trial block
    deltaShift = (-sz/2 + [row, col]);
    % extract the test sample feature map for the translation filter
    xt = get_translation_sample(im, pos, sz, [swcf.currentScaleFactorX swcf.currentScaleFactorY], imtranslate(swcf.cos_window, [1 1].*deltaShift(end:-1:1)));
    
    % calculate the correlation response of the translation filter
    xtf = fft2(xt);
    response = real(ifft2(sum(swcf.hf_num .* xtf, 3) ./ (swcf.hf_den + swcf.lambda)));
    
    % find the maximum translation response
    [row, col] = find(response == max(response(:)), 1);
    %%
    swcf.maxResponse = max(response(:));
    swcf.psrPrev = swcf.psr;
    swcf.psr = (max(max(response))-mean(mean(response)))/sqrt(var(response(:)));
    swcf.psrs = [swcf.psrs swcf.psr];
    % update the position
    pos = pos + round((-sz/2 + [row, col]) .* [swcf.currentScaleFactorY swcf.currentScaleFactorX]);
    
    % extract the test sample feature map for the scale filter
    [xsX, xsY] = get_scale_sample_for1D(im, pos, swcf.base_target_sz, swcf.currentScaleFactorX * swcf.scaleFactorsX, swcf.currentScaleFactorY * swcf.scaleFactorsY, swcf.scale_window, swcf.scale_model_sz);
    
    % calculate the correlation response of the scale filter
    xsfX = fft(xsX,[],2);
    scale_responseX = real(ifft(sum(swcf.sf_numX .* xsfX, 1) ./ (swcf.sf_denX + swcf.lambda)));
    xsfY = fft(xsY,[],2);
    scale_responseY = real(ifft(sum(swcf.sf_numY .* xsfY, 1) ./ (swcf.sf_denY + swcf.lambda)));
    
    % find the maximum scale response
    recovered_scaleX = find(scale_responseX == max(scale_responseX(:)), 1);
    recovered_scaleY = find(scale_responseY == max(scale_responseY(:)), 1);
    
    % update the scale
    swcf.currentScaleFactorX = swcf.currentScaleFactorX * swcf.scaleFactorsX(recovered_scaleX);
    swcf.currentScaleFactorY = swcf.currentScaleFactorY * swcf.scaleFactorsY(recovered_scaleY);
    %     swcf.currentScaleFactorX = 1; swcf.currentScaleFactorY = 1;
    
    
    
    if swcf.currentScaleFactorX < swcf.min_scale_factor
        swcf.currentScaleFactorX = swcf.min_scale_factor;
    elseif swcf.currentScaleFactorX > swcf.max_scale_factor
        swcf.currentScaleFactorX = swcf.max_scale_factor;
    end
    
    if swcf.currentScaleFactorY < swcf.min_scale_factor
        swcf.currentScaleFactorY = swcf.min_scale_factor;
    elseif swcf.currentScaleFactorY > swcf.max_scale_factor
        swcf.currentScaleFactorY = swcf.max_scale_factor;
    end
    
end

% extract the training sample feature map for the translation filter
xl = get_translation_sample(im, pos, sz, [swcf.currentScaleFactorX swcf.currentScaleFactorY], swcf.plain_window);
[ output_args ] = learningthemask( swcf, xl);
swcf.cos_window = output_args;
xl = get_translation_sample(im, pos, sz, [swcf.currentScaleFactorX swcf.currentScaleFactorY], swcf.cos_window_fixed);

% calculate the translation filter update
xlf = fft2(xl);
new_hf_num = bsxfun(@times, swcf.yf, conj(xlf));
new_hf_den = sum(xlf .* conj(xlf), 3);

% extract the training sample feature map for the scale filter
[xsX, xsY] = get_scale_sample_for1D(im, pos, swcf.base_target_sz, swcf.currentScaleFactorX * swcf.scaleFactorsX, swcf.currentScaleFactorY * swcf.scaleFactorsY, swcf.scale_window, swcf.scale_model_sz);

% calculate the scale filter update
xsfX = fft(xsX,[],2);
new_sf_numX = bsxfun(@times, swcf.ysf, conj(xsfX));
new_sf_denX = sum(xsfX .* conj(xsfX), 1);
xsfY = fft(xsY,[],2);
new_sf_numY = bsxfun(@times, swcf.ysf, conj(xsfY));
new_sf_denY = sum(xsfY .* conj(xsfY), 1);


if swcf.flag == 0 %frame == 1
    % first frame, train with a single image
    swcf.hf_den = new_hf_den;
    swcf.hf_num = new_hf_num;
    
    swcf.sf_denX = new_sf_denX;
    swcf.sf_numX = new_sf_numX;
    swcf.sf_denY = new_sf_denY;
    swcf.sf_numY = new_sf_numY;
else
    % subsequent frames, update the model
    swcf.hf_den = (1 - swcf.learning_rate) * swcf.hf_den + swcf.learning_rate * new_hf_den;
    swcf.hf_num = (1 - swcf.learning_rate) * swcf.hf_num + swcf.learning_rate * new_hf_num;
    swcf.sf_denX = (1 - swcf.learning_rate) * swcf.sf_denX + swcf.learning_rate * new_sf_denX;
    swcf.sf_numX = (1 - swcf.learning_rate) * swcf.sf_numX + swcf.learning_rate * new_sf_numX;
    swcf.sf_denY = (1 - swcf.learning_rate) * swcf.sf_denY + swcf.learning_rate * new_sf_denY;
    swcf.sf_numY = (1 - swcf.learning_rate) * swcf.sf_numY + swcf.learning_rate * new_sf_numY;
end

% calculate the new target size
target_sz = floor(swcf.base_target_sz .* [swcf.currentScaleFactorY swcf.currentScaleFactorX]);

swcf.time = swcf.time + toc;
swcf.pos = pos;
swcf.sz = sz;
swcf.rect = [pos([2,1]) - target_sz([2,1])/2, target_sz([2,1])];
swcf.flag = 1;

end

